@@ -14,6 +14,7 @@
 import matplotlib as mpl
 import numpy.testing as npt
 import torch
+import torch.nn.functional as F
 
 mpl.use("Agg")
 import matplotlib.pyplot as plt  # noqa
@@ -46,3 +47,10 @@ def test_ccep_calculation():
     magphase = torch.exp(logmagphase)
     x_ret2 = torch.fft.ifft(magphase, n=fft_size, dim=-1).real
     npt.assert_almost_equal(x.numpy(), x_ret2.numpy(), decimal=5)
+
+
+def test_conv1d():
+    x = torch.randn(1, 1, 1024 + 256 * 2 - 1)
+    k = torch.randn(1, 2, 1024)
+    _ = F.conv1d(x[..., :-256], k[:, :1])
+    _ = F.conv1d(x[..., 256:], k[:, 1:])
